Module: Google::Cloud::RecommendationEngine
- Defined in:
- lib/google/cloud/recommendation_engine.rb,
lib/google/cloud/recommendation_engine/version.rb
Constant Summary collapse
- VERSION =
"0.9.0"
Class Method Summary collapse
-
.catalog_service(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CatalogService.
-
.catalog_service_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the CatalogService service is supported by the current client.
-
.configure {|::Google::Cloud.configure.recommendation_engine| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-recommendation_engine library.
-
.prediction_api_key_registry(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PredictionApiKeyRegistry.
-
.prediction_api_key_registry_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the PredictionApiKeyRegistry service is supported by the current client.
-
.prediction_service(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PredictionService.
-
.prediction_service_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the PredictionService service is supported by the current client.
-
.user_event_service(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserEventService.
-
.user_event_service_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the UserEventService service is supported by the current client.
Class Method Details
.catalog_service(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CatalogService.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::CatalogService::Client
for a gRPC client for version V1beta1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CatalogService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CatalogService service. You can determine whether the method will succeed by calling catalog_service_available?.
About CatalogService
Service for ingesting catalog information of the customer's website.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/recommendation_engine.rb', line 75 def self.catalog_service version: :v1beta1, transport: :grpc, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::RecommendationEngine.const_get(package_name).const_get(:CatalogService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.catalog_service_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the CatalogService service is supported by the current client. If true, you can retrieve a client object by calling catalog_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CatalogService service, or if the versioned client gem needs an update to support the CatalogService service.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/google/cloud/recommendation_engine.rb', line 99 def self.catalog_service_available? version: :v1beta1, transport: :grpc require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::RecommendationEngine.const_get package_name return false unless service_module.const_defined? :CatalogService service_module = service_module.const_get :CatalogService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.recommendation_engine| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-recommendation_engine library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
361 362 363 364 365 |
# File 'lib/google/cloud/recommendation_engine.rb', line 361 def self.configure yield ::Google::Cloud.configure.recommendation_engine if block_given? ::Google::Cloud.configure.recommendation_engine end |
.prediction_api_key_registry(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PredictionApiKeyRegistry.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::PredictionApiKeyRegistry::Client
for a gRPC client for version V1beta1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the PredictionApiKeyRegistry service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PredictionApiKeyRegistry service. You can determine whether the method will succeed by calling prediction_api_key_registry_available?.
About PredictionApiKeyRegistry
Service for registering API keys for use with the predict method. If you
use an API key to request predictions, you must first register the API key.
Otherwise, your prediction request is rejected. If you use OAuth to
authenticate your predict method call, you do not need to register an API
key. You can register up to 20 API keys per project.
149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/google/cloud/recommendation_engine.rb', line 149 def self.prediction_api_key_registry version: :v1beta1, transport: :grpc, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::RecommendationEngine.const_get(package_name).const_get(:PredictionApiKeyRegistry) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.prediction_api_key_registry_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the PredictionApiKeyRegistry service is supported by the current client. If true, you can retrieve a client object by calling prediction_api_key_registry. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PredictionApiKeyRegistry service, or if the versioned client gem needs an update to support the PredictionApiKeyRegistry service.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/google/cloud/recommendation_engine.rb', line 173 def self.prediction_api_key_registry_available? version: :v1beta1, transport: :grpc require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::RecommendationEngine.const_get package_name return false unless service_module.const_defined? :PredictionApiKeyRegistry service_module = service_module.const_get :PredictionApiKeyRegistry if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.prediction_service(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PredictionService.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::PredictionService::Client
for a gRPC client for version V1beta1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the PredictionService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PredictionService service. You can determine whether the method will succeed by calling prediction_service_available?.
About PredictionService
Service for making recommendation prediction.
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/google/cloud/recommendation_engine.rb', line 219 def self.prediction_service version: :v1beta1, transport: :grpc, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::RecommendationEngine.const_get(package_name).const_get(:PredictionService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.prediction_service_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the PredictionService service is supported by the current client. If true, you can retrieve a client object by calling prediction_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PredictionService service, or if the versioned client gem needs an update to support the PredictionService service.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/google/cloud/recommendation_engine.rb', line 243 def self.prediction_service_available? version: :v1beta1, transport: :grpc require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::RecommendationEngine.const_get package_name return false unless service_module.const_defined? :PredictionService service_module = service_module.const_get :PredictionService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.user_event_service(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for UserEventService.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::UserEventService::Client
for a gRPC client for version V1beta1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the UserEventService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the UserEventService service. You can determine whether the method will succeed by calling user_event_service_available?.
About UserEventService
Service for ingesting end user actions on the customer website.
289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/google/cloud/recommendation_engine.rb', line 289 def self.user_event_service version: :v1beta1, transport: :grpc, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::RecommendationEngine.const_get(package_name).const_get(:UserEventService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.user_event_service_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the UserEventService service is supported by the current client. If true, you can retrieve a client object by calling user_event_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the UserEventService service, or if the versioned client gem needs an update to support the UserEventService service.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/google/cloud/recommendation_engine.rb', line 313 def self.user_event_service_available? version: :v1beta1, transport: :grpc require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::RecommendationEngine.const_get package_name return false unless service_module.const_defined? :UserEventService service_module = service_module.const_get :UserEventService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |