Module: Google::Cloud::RecommendationEngine
- Defined in:
- lib/google/cloud/recommendation_engine.rb,
lib/google/cloud/recommendation_engine/version.rb
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
-
.catalog_service(version: :v1beta1, &block) ⇒ CatalogService::Client
Create a new client object for CatalogService.
-
.configure {|::Google::Cloud.configure.recommendation_engine| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-recommendation_engine library.
-
.prediction_api_key_registry(version: :v1beta1, &block) ⇒ PredictionApiKeyRegistry::Client
Create a new client object for PredictionApiKeyRegistry.
-
.prediction_service(version: :v1beta1, &block) ⇒ PredictionService::Client
Create a new client object for PredictionService.
-
.user_event_service(version: :v1beta1, &block) ⇒ UserEventService::Client
Create a new client object for UserEventService.
Class Method Details
.catalog_service(version: :v1beta1, &block) ⇒ CatalogService::Client
Create a new client object for CatalogService.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::CatalogService::Client
for version V1beta1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the CatalogService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About CatalogService
Service for ingesting catalog information of the customer's website.
66 67 68 69 70 71 72 73 74 75 |
# File 'lib/google/cloud/recommendation_engine.rb', line 66 def self.catalog_service version: :v1beta1, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::RecommendationEngine.const_get package_name package_module.const_get(:CatalogService).const_get(:Client).new(&block) end |
.configure {|::Google::Cloud.configure.recommendation_engine| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-recommendation_engine library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Integer) - Default timeout in milliseconds.metadata(type:Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.-
retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys:* `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. * `:retry_codes` (*type:* `Array<String>`) - The error codes that should trigger a retry.
199 200 201 202 203 |
# File 'lib/google/cloud/recommendation_engine.rb', line 199 def self.configure yield ::Google::Cloud.configure.recommendation_engine if block_given? ::Google::Cloud.configure.recommendation_engine end |
.prediction_api_key_registry(version: :v1beta1, &block) ⇒ PredictionApiKeyRegistry::Client
Create a new client object for PredictionApiKeyRegistry.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::PredictionApiKeyRegistry::Client
for version V1beta1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the PredictionApiKeyRegistry service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About PredictionApiKeyRegistry
Service for registering API keys for use with the predict method. If you
use an API key to request predictions, you must first register the API key.
Otherwise, your prediction request is rejected. If you use OAuth to
authenticate your predict method call, you do not need to register an API
key. You can register up to 20 API keys per project.
100 101 102 103 104 105 106 107 108 109 |
# File 'lib/google/cloud/recommendation_engine.rb', line 100 def self.prediction_api_key_registry version: :v1beta1, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::RecommendationEngine.const_get package_name package_module.const_get(:PredictionApiKeyRegistry).const_get(:Client).new(&block) end |
.prediction_service(version: :v1beta1, &block) ⇒ PredictionService::Client
Create a new client object for PredictionService.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::PredictionService::Client
for version V1beta1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the PredictionService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About PredictionService
Service for making recommendation prediction.
130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/cloud/recommendation_engine.rb', line 130 def self.prediction_service version: :v1beta1, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::RecommendationEngine.const_get package_name package_module.const_get(:PredictionService).const_get(:Client).new(&block) end |
.user_event_service(version: :v1beta1, &block) ⇒ UserEventService::Client
Create a new client object for UserEventService.
By default, this returns an instance of
Google::Cloud::RecommendationEngine::V1beta1::UserEventService::Client
for version V1beta1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the UserEventService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About UserEventService
Service for ingesting end user actions on the customer website.
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/google/cloud/recommendation_engine.rb', line 160 def self.user_event_service version: :v1beta1, &block require "google/cloud/recommendation_engine/#{version.to_s.downcase}" package_name = Google::Cloud::RecommendationEngine .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::RecommendationEngine.const_get package_name package_module.const_get(:UserEventService).const_get(:Client).new(&block) end |